==> backwpup_0b6ee2_2018-06-01_04-17-45.tar.gz: wp-config.php <==
<?php
/**
 * The base configurations of the WordPress.
 *
 * This file has the following configurations: MySQL settings, Table Prefix,
 * Secret Keys, WordPress Language, and ABSPATH. You can find more information
 * by visiting {@link http://codex.wordpress.org/Editing_wp-config.php Editing
 * wp-config.php} Codex page. You can get the MySQL settings from your web host.
 *
 * This file is used by the wp-config.php creation script during the
 * installation. You don't have to use the web site, you can just copy this file
 * to "wp-config.php" and fill in the values.
 *
 * @package WordPress
 */

// ** MySQL settings - You can get this info from your web host ** //
/** The name of the database for WordPress */
define('DB_NAME', 'ccookiefbjccoofr');

/** MySQL database username */
define('DB_USER', 'ccookiefbjccoofr');

/** MySQL database password */
define('DB_PASSWORD', '2lRHJ8RkVGTe');

/** MySQL hostname */
define('DB_HOST', 'ccookiefbjccoofr.mysql.db');

/** Database Charset to use in creating database tables. */
define('DB_CHARSET', 'utf8');

/** The Database Collate type. Don't change this if in doubt. */
define('DB_COLLATE', '');

/**#@+
 * Authentication Unique Keys and Salts.
 *
 * Change these to different unique phrases!
 * You can generate these using the {@link https://api.wordpress.org/secret-key/1.1/salt/ WordPress.org secret-key service}
 * You can change these at any point in time to invalidate all existing cookies. This will force all users to have to log in again.
 *
 * @since 2.6.0
 */
define('AUTH_KEY',         'x,6}1=^t;E@HG{vft:6Bo|oV!(7Vy||i;D;X?CMtjou+:*!Y1!J(R]VzRO2Vdu+o');
define('SECURE_AUTH_KEY',  'Ts~o>0vIQL[0qGQ4~-,-4G&-7Dser1%{_ga>R1l}2* Q|]#&n3|3#vw_u:9z#NC)');
define('LOGGED_IN_KEY',    '43ySV?K-XTL?]Q0+Fg;]U=+wKnZh_Ou>EDMD7tpSzC.;|Uq(/JDv]GJe&`UfVizh');
define('NONCE_KEY',        ',^,@LlTJ3/rpV-^{30tH#+vyH:d?uLcqBPn5}}dD7NyGCzdJ{2!R%-s)r*~D=wb+');
define('AUTH_SALT',        '{z.nm$2<;6+/7/^lz-.0tS4r*YA5_k1~L7klQFKI~+$EubD/S,i~Dt3z9b=kPUwV');
define('SECURE_AUTH_SALT', ';`Gnu?GmF!4)ar2$#^bN4}R-sea+->O!0!+@&{Bo?u4-Z6G$zeBrg/gr=TtKq|<6');
define('LOGGED_IN_SALT',   'I>V_&w`|su_JTkcgw?w6[C@64aC,@]qjh4&NE9gVd/H-EE@jLb2P)NdSsuvM@ySI');
define('NONCE_SALT',       '0rXzR#q5)+X1Ff@}l+/M=?EDvC3oWa<|94/~|N-y,EDt4 ;;7O|&F{%%B$b@blD+');

/**#@-*/

/**
 * WordPress Database Table prefix.
 *
 * You can have multiple installations in one database if you give each a unique
 * prefix. Only numbers, letters, and underscores please!
 */
$table_prefix  = 'wp_';

/**
 * WordPress Localized Language, defaults to English.
 *
 * Change this to localize WordPress. A corresponding MO file for the chosen
 * language must be installed to wp-content/languages. For example, install
 * de_DE.mo to wp-content/languages and set WPLANG to 'de_DE' to enable German
 * language support.
 */
define('WPLANG', 'fr_FR');

/**
 * For developers: WordPress debugging mode.
 *
 * Change this to true to enable the display of notices during development.
 * It is strongly recommended that plugin and theme developers use WP_DEBUG
 * in their development environments.
 */
define('WP_DEBUG', false);

/* That's all, stop editing! Happy blogging. */

/** Absolute path to the WordPress directory. */
if ( !defined('ABSPATH') )
	define('ABSPATH', dirname(__FILE__) . '/');

/** Sets up WordPress vars and included files. */
require_once(ABSPATH . 'wp-settings.php');

==> backwpup_0b6ee2_2018-06-16_03-38-03.tar.gz: wp-config.php <==
<?php
/**
 * The base configurations of the WordPress.
 *
 * This file has the following configurations: MySQL settings, Table Prefix,
 * Secret Keys, WordPress Language, and ABSPATH. You can find more information
 * by visiting {@link http://codex.wordpress.org/Editing_wp-config.php Editing
 * wp-config.php} Codex page. You can get the MySQL settings from your web host.
 *
 * This file is used by the wp-config.php creation script during the
 * installation. You don't have to use the web site, you can just copy this file
 * to "wp-config.php" and fill in the values.
 *
 * @package WordPress
 */

// ** MySQL settings - You can get this info from your web host ** //
/** The name of the database for WordPress */
define('DB_NAME', 'ccookiefbjccoofr');

/** MySQL database username */
define('DB_USER', 'ccookiefbjccoofr');

/** MySQL database password */
define('DB_PASSWORD', '2lRHJ8RkVGTe');

/** MySQL hostname */
define('DB_HOST', 'ccookiefbjccoofr.mysql.db');

/** Database Charset to use in creating database tables. */
define('DB_CHARSET', 'utf8');

/** The Database Collate type. Don't change this if in doubt. */
define('DB_COLLATE', '');

/**#@+
 * Authentication Unique Keys and Salts.
 *
 * Change these to different unique phrases!
 * You can generate these using the {@link https://api.wordpress.org/secret-key/1.1/salt/ WordPress.org secret-key service}
 * You can change these at any point in time to invalidate all existing cookies. This will force all users to have to log in again.
 *
 * @since 2.6.0
 */
define('AUTH_KEY',         'x,6}1=^t;E@HG{vft:6Bo|oV!(7Vy||i;D;X?CMtjou+:*!Y1!J(R]VzRO2Vdu+o');
define('SECURE_AUTH_KEY',  'Ts~o>0vIQL[0qGQ4~-,-4G&-7Dser1%{_ga>R1l}2* Q|]#&n3|3#vw_u:9z#NC)');
define('LOGGED_IN_KEY',    '43ySV?K-XTL?]Q0+Fg;]U=+wKnZh_Ou>EDMD7tpSzC.;|Uq(/JDv]GJe&`UfVizh');
define('NONCE_KEY',        ',^,@LlTJ3/rpV-^{30tH#+vyH:d?uLcqBPn5}}dD7NyGCzdJ{2!R%-s)r*~D=wb+');
define('AUTH_SALT',        '{z.nm$2<;6+/7/^lz-.0tS4r*YA5_k1~L7klQFKI~+$EubD/S,i~Dt3z9b=kPUwV');
define('SECURE_AUTH_SALT', ';`Gnu?GmF!4)ar2$#^bN4}R-sea+->O!0!+@&{Bo?u4-Z6G$zeBrg/gr=TtKq|<6');
define('LOGGED_IN_SALT',   'I>V_&w`|su_JTkcgw?w6[C@64aC,@]qjh4&NE9gVd/H-EE@jLb2P)NdSsuvM@ySI');
define('NONCE_SALT',       '0rXzR#q5)+X1Ff@}l+/M=?EDvC3oWa<|94/~|N-y,EDt4 ;;7O|&F{%%B$b@blD+');
define( 'FORCE_SSL_LOGIN', true );
define( 'FORCE_SSL_ADMIN', true );
define( 'DISALLOW_FILE_EDIT', true );

/**#@-*/

/**
 * WordPress Database Table prefix.
 *
 * You can have multiple installations in one database if you give each a unique
 * prefix. Only numbers, letters, and underscores please!
 */
$table_prefix  = 'wp_';

/**
 * WordPress Localized Language, defaults to English.
 *
 * Change this to localize WordPress. A corresponding MO file for the chosen
 * language must be installed to wp-content/languages. For example, install
 * de_DE.mo to wp-content/languages and set WPLANG to 'de_DE' to enable German
 * language support.
 */
define('WPLANG', 'fr_FR');

/**
 * For developers: WordPress debugging mode.
 *
 * Change this to true to enable the display of notices during development.
 * It is strongly recommended that plugin and theme developers use WP_DEBUG
 * in their development environments.
 */
define('WP_DEBUG', false);

/* That's all, stop editing! Happy blogging. */

/** Absolute path to the WordPress directory. */
if ( !defined('ABSPATH') )
	define('ABSPATH', dirname(__FILE__) . '/');

/** Sets up WordPress vars and included files. */
require_once(ABSPATH . 'wp-settings.php');
